__author__ = 'Xiaoou WANG'


def max(a, b):
    if a >= b:
        return a
    else:
        return b